use gtk4 :: { * , prelude :: * } ;

use crate :: {
	collection :: * ,
	ui :: { collated_grid :: * , collation_menu :: * , utility :: * } ,
	utility :: * ,
} ;



pub struct CollatableFilmsContainer {
	collated_grid : & 'static CollatedFilmsGrid ,
	widget : gtk4 :: Box ,
}
pub struct CollatableSeriesContainer {
	collated_grid : & 'static CollatedSeriesGrid ,
	widget : gtk4 :: Box ,
}

impl CollatableFilmsContainer {
	pub fn new ( films : Vec <Film> ) -> Self {
		let collated_grid = leak ( CollatedFilmsGrid :: new ( films , FilmsSortedBy :: Name ) ) ;
		let widget = create_vertical_box ! (
			& create_film_collection_menu ( |sorted_by| {
				collated_grid . set_sorting (sorted_by) ;
			} ) ,
			& create_collection_scrolled_window ( collated_grid . get_widget () ) ,
		) ;

		Self { collated_grid , widget }
	}

	pub fn set_films ( & self , films : Vec <Film> ) {
		self . collated_grid . set_films ( films , FilmsSortedBy :: Name ) ;
	}

	pub fn get_widget ( & self ) -> & gtk4 :: Box { & self . widget }
}
impl CollatableSeriesContainer {
	pub fn new ( series : Vec <Series> ) -> Self {
		let collated_grid = leak ( CollatedSeriesGrid :: new ( series , SeriesSortedBy :: Name ) ) ;
		let widget = create_vertical_box ! (
			& create_series_collection_menu ( |sorted_by| {
				collated_grid . set_sorting (sorted_by) ;
			} ) ,
			& create_collection_scrolled_window ( collated_grid . get_widget () ) ,
		) ;

		Self { collated_grid , widget }
	}

	pub fn set_series ( & self , series : Vec <Series> ) {
		self . collated_grid . set_series ( series , SeriesSortedBy :: Name ) ;
	}

	pub fn get_widget ( & self ) -> & gtk4 :: Box { & self . widget }
}

fn create_collection_scrolled_window ( child : & FlowBox ) -> ScrolledWindow {
	ScrolledWindow :: builder ()
		. child ( & create_vertical_filler_container (child) )
		. propagate_natural_height (true)
		. build ()
}
