mod collatable_container ;
mod collated_grid ;
mod collation_menu ;
mod internal ;
mod utility ;

use { gtk4 :: prelude :: * , libadwaita :: * } ;

use crate :: {
	collection :: * ,
	ui :: { collatable_container :: * , internal :: * , utility :: * } ,
} ;



pub struct UI {
	window : ApplicationWindow ,
	films_container : CollatableFilmsContainer ,
	series_container : CollatableSeriesContainer ,
}

impl UI {
	pub fn new ( application : & Application ) -> UI {
		let films_container = CollatableFilmsContainer :: new ( vec ! () ) ;
		let series_container = CollatableSeriesContainer :: new ( vec ! () ) ;
		let collection_view_stack = create_view_stack ! (
			"Films" , "camera-video-symbolic" , films_container . get_widget () ,
			"Series" , "video-display-symbolic" , series_container . get_widget () ,
		) ;
		let header_bar = create_header_bar ( & collection_view_stack ) ;
		let window = create_window ( application , & header_bar , & collection_view_stack ) ;

		UI { window , films_container , series_container }
	}

	pub fn show_window ( & self ) { self . window . set_visible (true) }

	pub fn render_collection ( & self , collection : Collection ) {
		self . films_container . set_films ( collection . films ) ;
		self . series_container . set_series ( collection . series ) ;
	}
}
